<?php

namespace apexl\Io\modules\invoice\providers;

use Psr\Http\Message\ServerRequestInterface as Request;

interface providerInterface
{
    public function getInvoices($email);
    public function createInvoice($lineitems, $contactData, $dueDate, $desc, $branding, $sendEmail, $type, $currency);
    public function getInvoiceUrl($invoiceId);
    public function processWebhookRequest(Request $request);
}